function [s,s_dot,p,v,c] = DSFLocUknPropSpdStnySrc_CnstgConf(N,s_min_dis,d_s_dis,s_dot_dis,KK)
% function [s,s_dot,p,v,c] = DSFLocUknPropSpdStnySrc_CnstgConf(N,s_min_dis,d_s_dis,s_dot_dis,KK)
%
% Construction of configurations for stationary object localization by
% frequency measurments when signal propagation speed is not known.
% 
% Input:
%   N:           (1 x 1), number of sensors
%   s_min_dis:   (1 x 1), the distance between sensors
%   d_s_dis:     (1 x 1), the distance between source and sensors
%   s_dot_dis:   (1 x 1), the distance between the velocities of sensors
%   KK:          (1 x 1), the number of configurations
%
% Output:
%   s:        (2 x N), the true value of sensor positions
%   s_dot:    (2 x N), the true value of sensor velocities
%   p:        (2 x 1), the true value of source position
%   v:        (2 x 1), the true value of source velocity
%   c:        (1 x 1), the true value of signal propagation speed
%
% Reference:
% D. Lin, G. Wang, K. C. Ho, and L. Huang, "Source localization by frequency
% measurements in unknown signal propagation speed environments," IEEE
% Trans. Aerosp. Electron. Syst., vol. 59, no. 4, pp. 3953-3970, Aug. 2023.
%
% Danyan Lin, Gang Wang, K. C. Ho	Nov. 1, 2023
%
%       Copyright (C) 2023
%       the Faculty of Electrical Engineering and Computer Science
%       Ningbo University
%       Ningbo 315211, China
%       wanggang@nbu.edu.cn
%

warning('off');

rand('seed',9);
for kk=1:KK
    a=0;
    while a<s_min_dis  %to guarantee the distance between arbitrary sensors 
                       %is larger than s_min_dis
        s_0 = 1000*(2*rand(2,N)-1)*1e-3;%km  
        for i=1:N-1
            for j=i+1:N
                a_0(i,j) = norm(s_0(:,i)-s_0(:,j));
            end
            a(i) = min(a_0(i,i+1:N));
        end
        a = min(a);
    end
    s(:,:,kk) = s_0;
    b = 0;
    while b<d_s_dis   %to guarantee the distance between source and an 
                      %arbitrary sensor is larger than d_s_dis
        p_0 = 1000*(2*rand(2,1)-1)*1e-3;%km
        for i=1:N
            b_0(i) = norm(s_0(:,i)-p_0); 
        end
        b = min(b_0);
    end
    p(:,:,kk) = p_0;
    cc = 0;
    while cc<s_dot_dis %to guarantee the distance between the velocities 
                       %of arbitrary sensors is larger than s_min_dis
        s_dot_0 = 15*(2*rand(2,N)-1)*1e-3;%km/s
        for i=1:N-1
            for j=i+1:N
                c_0(i,j) = norm(s_dot_0(:,i)-s_dot_0(:,j));
            end
            cc(i) = min(c_0(i,i+1:N));
        end
        cc = min(cc);
    end
    s_dot(:,:,kk) = s_dot_0;%km
    v(:,:,kk) = 15*(2*rand(2,1)-1)*1e-3;%km
    c(kk) = 1.45+0.05*rand(1);%km/s
end